/* registration code for setting up the alpha channel plugin */
{
   extern DATEDIT_MENU_INFO datalpha_menu1;
   extern DATEDIT_MENU_INFO datalpha_menu2;

   datedit_register_menu(&datalpha_menu1);
   datedit_register_menu(&datalpha_menu2);
}

/* registration code for setting up the FLI object plugin */
{
   extern DATEDIT_OBJECT_INFO datfli_info;
   extern DATEDIT_GRABBER_INFO datfli_grabber;

   datedit_register_object(&datfli_info);
   datedit_register_grabber(&datfli_grabber);
}

/* registration code for setting up the filename conversion plugin */
{
   extern DATEDIT_MENU_INFO datfname_type_menu;

   datedit_register_menu(&datfname_type_menu);
}

/* registration code for setting up the font object plugin */
{
   extern DATEDIT_OBJECT_INFO datfont_info;
   extern DATEDIT_GRABBER_INFO datfont_grabber;

   datedit_register_object(&datfont_info);
   datedit_register_grabber(&datfont_grabber);
}

/* registration code for setting up the interactive region grab plugin */
{
   extern DATEDIT_MENU_INFO datgrab_grabber_menu;
   extern DATEDIT_MENU_INFO datgrab_boxgrab_menu;
   extern DATEDIT_MENU_INFO datgrab_ungrab_menu;

   datedit_register_menu(&datgrab_grabber_menu);
   datedit_register_menu(&datgrab_boxgrab_menu);
   datedit_register_menu(&datgrab_ungrab_menu);
}

/* registration code for setting up the grab-from-grid plugin */
{
   extern DATEDIT_MENU_INFO datgrid_griddler_menu;
   extern DATEDIT_MENU_INFO datgrid_autocrop_menu;
   extern void datgrid_init(void);

   datedit_register_menu(&datgrid_griddler_menu);
   datedit_register_menu(&datgrid_autocrop_menu);

   datgrid_init();
}

/* registration code for setting up the bitmapped image plugin */
{
   extern DATEDIT_OBJECT_INFO datbitmap_info;
   extern DATEDIT_GRABBER_INFO datbitmap_grabber;

   extern DATEDIT_OBJECT_INFO datrlesprite_info;
   extern DATEDIT_GRABBER_INFO datrlesprite_grabber;

   extern DATEDIT_OBJECT_INFO datcsprite_info;
   extern DATEDIT_GRABBER_INFO datcsprite_grabber;

   extern DATEDIT_OBJECT_INFO datxcsprite_info;
   extern DATEDIT_GRABBER_INFO datxcsprite_grabber;

   datedit_register_object(&datbitmap_info);
   datedit_register_grabber(&datbitmap_grabber);

   datedit_register_object(&datrlesprite_info);
   datedit_register_grabber(&datrlesprite_grabber);

   datedit_register_object(&datcsprite_info);
   datedit_register_grabber(&datcsprite_grabber);

   datedit_register_object(&datxcsprite_info);
   datedit_register_grabber(&datxcsprite_grabber);
}

/* registration code for setting up the image format conversion plugin */
{
   extern DATEDIT_MENU_INFO datitype_type_menu;
   extern DATEDIT_MENU_INFO datitype_depth_menu;

   datedit_register_menu(&datitype_type_menu);
   datedit_register_menu(&datitype_depth_menu);
}

/* registration code for setting up the MIDI object plugin */
{
   extern DATEDIT_OBJECT_INFO datmidi_info;
   extern DATEDIT_GRABBER_INFO datmidi_grabber;

   datedit_register_object(&datmidi_info);
   datedit_register_grabber(&datmidi_grabber);
}

/* registration code for setting up the palette object plugin */
{
   extern DATEDIT_OBJECT_INFO datpal_info;
   extern DATEDIT_GRABBER_INFO datpal_grabber;
   extern DATEDIT_MENU_INFO datpal_grabber_menu;

   datedit_register_object(&datpal_info);
   datedit_register_grabber(&datpal_grabber);
   datedit_register_menu(&datpal_grabber_menu);
}

/* registration code for setting up the sample object plugin */
{
   extern DATEDIT_OBJECT_INFO datsample_info;
   extern DATEDIT_GRABBER_INFO datsample_grabber;

   extern DATEDIT_OBJECT_INFO datpatch_info;
   extern DATEDIT_GRABBER_INFO datpatch_grabber;

   datedit_register_object(&datsample_info);
   datedit_register_grabber(&datsample_grabber);

   datedit_register_object(&datpatch_info);
   datedit_register_grabber(&datpatch_grabber);
}

/* registration code for setting up the most pointless plugin of all */
{
   extern DATEDIT_MENU_INFO datworms_menu;

   datedit_register_menu(&datworms_menu);
}

/* registration code for setting up the JPEG image plugin */
{
   extern DATEDIT_OBJECT_INFO datjpeg_info;
   extern DATEDIT_GRABBER_INFO datjpeg_grabber;
   extern DATEDIT_MENU_INFO datjpeg_menu;

   datedit_register_object(&datjpeg_info);
   datedit_register_grabber(&datjpeg_grabber);
   datedit_register_menu(&datjpeg_menu);
}

